==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListConnectionConsentLinksPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property connectionName Connection name
 * @property parameters Collection of resources
 * @property resourceGroupName The resource group
 * @property subscriptionId Subscription Id
 */
public data class ListConnectionConsentLinksPlainArgs(
    public val connectionName: String,
    public val parameters: List<ConsentLinkParameterDefinition>? = null,
    public val resourceGroupName: String,
    public val subscriptionId: String? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs =
        com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs.builder()
            .connectionName(connectionName.let({ args0 -> args0 }))
            .parameters(
                parameters?.let({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListConnectionConsentLinksPlainArgs].
 */
@PulumiTagMarker
public class ListConnectionConsentLinksPlainArgsBuilder internal constructor() {
    private var connectionName: String? = null

    private var parameters: List<ConsentLinkParameterDefinition>? = null

    private var resourceGroupName: String? = null

    private var subscriptionId: String? = null

    /**
     * @param value Connection name
     */
    @JvmName("hmgpcpenclavluup")
    public suspend fun connectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.connectionName = mapped
    }

    /**
     * @param value Collection of resources
     */
    @JvmName("agptshwvsssicgdq")
    public suspend fun parameters(`value`: List<ConsentLinkParameterDefinition>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.parameters = mapped
    }

    /**
     * @param argument Collection of resources
     */
    @JvmName("yphoqbvcfwyljosx")
    public suspend
    fun parameters(argument: List<suspend ConsentLinkParameterDefinitionBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConsentLinkParameterDefinitionBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = toBeMapped
        this.parameters = mapped
    }

    /**
     * @param argument Collection of resources
     */
    @JvmName("ssbjvupscrybxxcj")
    public suspend fun parameters(
        vararg
        argument: suspend ConsentLinkParameterDefinitionBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConsentLinkParameterDefinitionBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = toBeMapped
        this.parameters = mapped
    }

    /**
     * @param argument Collection of resources
     */
    @JvmName("olvqdbcxkrricgyf")
    public suspend
    fun parameters(argument: suspend ConsentLinkParameterDefinitionBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConsentLinkParameterDefinitionBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = toBeMapped
        this.parameters = mapped
    }

    /**
     * @param values Collection of resources
     */
    @JvmName("oqtlnxiuarggjjyy")
    public suspend fun parameters(vararg values: ConsentLinkParameterDefinition) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.parameters = mapped
    }

    /**
     * @param value The resource group
     */
    @JvmName("bbvuwxowihwfrfgc")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Subscription Id
     */
    @JvmName("mijaavilxsmmoupk")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.subscriptionId = mapped
    }

    internal fun build(): ListConnectionConsentLinksPlainArgs = ListConnectionConsentLinksPlainArgs(
        connectionName = connectionName ?: throw PulumiNullFieldException("connectionName"),
        parameters = parameters,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        subscriptionId = subscriptionId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListConnectionConsentLinksPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property connectionName Connection name
 * @property parameters Collection of resources
 * @property resourceGroupName The resource group
 * @property subscriptionId Subscription Id
 */
public data class ListConnectionConsentLinksPlainArgs(
    public val connectionName: String,
    public val parameters: List<ConsentLinkParameterDefinition>? = null,
    public val resourceGroupName: String,
    public val subscriptionId: String? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs =
        com.pulumi.azurenative.web.inputs.ListConnectionConsentLinksPlainArgs.builder()
            .connectionName(connectionName.let({ args0 -> args0 }))
            .parameters(
                parameters?.let({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .subscriptionId(subscriptionId?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListConnectionConsentLinksPlainArgs].
 */
@PulumiTagMarker
public class ListConnectionConsentLinksPlainArgsBuilder internal constructor() {
    private var connectionName: String? = null

    private var parameters: List<ConsentLinkParameterDefinition>? = null

    private var resourceGroupName: String? = null

    private var subscriptionId: String? = null

    /**
     * @param value Connection name
     */
    @JvmName("sjjlcqboeofrhgkb")
    public suspend fun connectionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.connectionName = mapped
    }

    /**
     * @param value Collection of resources
     */
    @JvmName("ubbwkciaykkcbmvu")
    public suspend fun parameters(`value`: List<ConsentLinkParameterDefinition>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.parameters = mapped
    }

    /**
     * @param argument Collection of resources
     */
    @JvmName("rmlmrmxnjykeohnk")
    public suspend
    fun parameters(argument: List<suspend ConsentLinkParameterDefinitionBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ConsentLinkParameterDefinitionBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = toBeMapped
        this.parameters = mapped
    }

    /**
     * @param argument Collection of resources
     */
    @JvmName("lxcwdeobcfjtouiu")
    public suspend fun parameters(
        vararg
        argument: suspend ConsentLinkParameterDefinitionBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ConsentLinkParameterDefinitionBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = toBeMapped
        this.parameters = mapped
    }

    /**
     * @param argument Collection of resources
     */
    @JvmName("cbplygqxkgqsoxcv")
    public suspend
    fun parameters(argument: suspend ConsentLinkParameterDefinitionBuilder.() -> Unit) {
        val toBeMapped = listOf(
            ConsentLinkParameterDefinitionBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = toBeMapped
        this.parameters = mapped
    }

    /**
     * @param values Collection of resources
     */
    @JvmName("vqfxuyukbrwuukrk")
    public suspend fun parameters(vararg values: ConsentLinkParameterDefinition) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.parameters = mapped
    }

    /**
     * @param value The resource group
     */
    @JvmName("rrqwixijxorabmui")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Subscription Id
     */
    @JvmName("dwurrpnrfjugojxp")
    public suspend fun subscriptionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.subscriptionId = mapped
    }

    internal fun build(): ListConnectionConsentLinksPlainArgs = ListConnectionConsentLinksPlainArgs(
        connectionName = connectionName ?: throw PulumiNullFieldException("connectionName"),
        parameters = parameters,
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        subscriptionId = subscriptionId,
    )
}
